@@ -1,3 +1,3 @@
-from .download_utils import download_decorator
+from .download_utils import download_decorator, download_file
 from .main_utils import import_module
-from .lib_decorators import get_from_config, expand_input, get_elapsed_time, rgb2bgr, cast_kwargs_dict
+from .lib_decorators import get_from_config, expand_input, get_elapsed_time, rgb2bgr, cast_kwargs_dict
\ No newline at end of file
